Learn R Programming

qgarch (version 0.1.0)

qgarch_lr_test: Likelihood ratio test for nested qgarch models

Description

Compares two fitted qgarch models using the likelihood ratio test.

Usage

qgarch_lr_test(restricted, unrestricted, df = NULL)

Value

A data frame with the likelihood ratio statistic, degrees of freedom, p-value, and the model names. The returned object has class c("qgarch_lr_test", "data.frame").

Arguments

restricted

A fitted qgarch object representing the restricted model.

unrestricted

A fitted qgarch object representing the unrestricted model.

df

Degrees of freedom for the test. If NULL, it is computed as the difference in the number of estimated coefficients.