Learn R Programming

qgarch (version 0.1.0)

qgarch_moments: Compute sample moments for a series

Description

Computes the sample mean, variance, skewness, and excess kurtosis for a numeric series, along with simple standard errors.

Usage

qgarch_moments(x, scale_mean_variance = 1)

Value

A list with elements:

estimate

Named numeric vector of moment estimates.

std_error

Named numeric vector of standard errors.

n

Number of usable observations.

The returned object has class "qgarch_moments".

Arguments

x

A numeric vector or a one-column data frame containing the series.

scale_mean_variance

A finite scalar used to rescale the reported mean and variance and their standard errors.