Compares two fitted qgarch models using the likelihood ratio test.
qgarch_lr_test(restricted, unrestricted, df = NULL)A data frame with the likelihood ratio statistic, degrees of freedom,
p-value, and the model names. The returned object has class
c("qgarch_lr_test", "data.frame").
A fitted qgarch object representing the restricted model.
A fitted qgarch object representing the unrestricted model.
Degrees of freedom for the test. If NULL, it is computed as the
difference in the number of estimated coefficients.