Computes the sample mean, variance, skewness, and excess kurtosis for a numeric series, along with simple standard errors.
qgarch_moments(x, scale_mean_variance = 1)A list with elements:
Named numeric vector of moment estimates.
Named numeric vector of standard errors.
Number of usable observations.
The returned object has class "qgarch_moments".
A numeric vector or a one-column data frame containing the series.
A finite scalar used to rescale the reported mean and variance and their standard errors.